@@ -1203,16 +1203,16 @@ class DisplayNativeCreativeSerializer(serializers.Serializer):
     '''
     creative advertisement type
     '''
-    ad_type = serializers.ChoiceField(choices=NATIVE_AD_TYPES, allow_blank=True, required=True)
+    ad_type = serializers.ChoiceField(choices=NATIVE_AD_TYPES, required=True)
     '''
     who will create teaser? - regiohelden or customer
     '''
-    teaser = serializers.ChoiceField(choices=CREATIVE_CREATORS, allow_blank=True, required=True)
+    teaser = serializers.ChoiceField(choices=CREATIVE_CREATORS, allow_null=True, required=True)
     '''
     who will create advertorial? - regiohelden or customer.
     required for `native_ad_in` and `native_ad_flow_ad_in` ads types.
     '''
-    advertorial = serializers.ChoiceField(choices=CREATIVE_CREATORS, allow_blank=True, required=False)
+    advertorial = serializers.ChoiceField(choices=CREATIVE_CREATORS, allow_null=True, required=False)
     '''
     customer wishes
     '''
@@ -1360,10 +1360,11 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
 
         age_group_from = data.get('age_group_from')
         age_group_to = data.get('age_group_to')
-        if age_group_from and not age_group_to:
-            errors.append({'age_group_to': required_message})
-        elif age_group_to and not age_group_from:
-            errors.append({'age_group_from': required_message})
+        if not (age_group_from and age_group_to):
+            if age_group_from and not age_group_to:
+                errors.append({'age_group_to': required_message})
+            elif age_group_to and not age_group_from:
+                errors.append({'age_group_from': required_message})
         elif age_group_to < age_group_from:
             errors.append({'age_group_from': '"age_group_from" should be greater or equal than "age_group_to".'})
 
